@@ -1,6 +1,7 @@
 /*
 Copyright 2008, 2009 Will Stephenson <wstephenson@kde.org>
 Copyright 2008, 2009 Sebastian Kügler <sebas@kde.org>
+Copyright 2011-2012 Lamarque V. Souza <lamarque@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -316,19 +317,6 @@ void NetworkManagerApplet::init()
         connect(m_popup, SIGNAL(configNeedsSaving()), this, SIGNAL(configNeedsSaving()));
     }
 
-    // m_activatables->init() must be called after SLOT(activatableAdded(RemoteActivatable*)) has been connected and
-    // NMPopup has been allocated.
-    m_activatables->init();
-    interfaceConnectionStateChanged();
-
-    // to force InterfaceItems to update their hasDefaultRoute state.
-    if (m_activeInterface) {
-        QMetaObject::invokeMethod(m_activeInterface, "connectionStateChanged",
-                                  Q_ARG(int, m_activeInterface->connectionState()),
-                                  Q_ARG(int, Solid::Control::NetworkInterfaceNm09::UnknownState),
-                                  Q_ARG(int, Solid::Control::NetworkInterfaceNm09::NoReason));
-    }
-
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.connect("org.kde.kded", "/org/kde/networkmanagement", "org.kde.networkmanagement", "ModuleReady", this, SLOT(finishInitialization()));
 
@@ -344,6 +332,21 @@ void NetworkManagerApplet::finishInitialization()
                                      QLatin1String("org.kde.networkmanagement"), QDBusConnection::sessionBus());
 
     networkmanagement.call(QLatin1String("FinishInitialization"));
+
+    // m_activatables->init() must be called after SLOT(activatableAdded(RemoteActivatable*,int)) has been connected and
+    // NMPopup has been allocated.
+    m_activatables->init();
+
+    // this needs m_activables initialized so that it can get the connection name to add to the InterfaceItem.
+    interfaceConnectionStateChanged();
+
+    // to force InterfaceItems to update their hasDefaultRoute state.
+    if (m_activeInterface) {
+        QMetaObject::invokeMethod(m_activeInterface, "connectionStateChanged",
+                                  Q_ARG(int, m_activeInterface->connectionState()),
+                                  Q_ARG(int, Solid::Control::NetworkInterfaceNm09::UnknownState),
+                                  Q_ARG(int, Solid::Control::NetworkInterfaceNm09::NoReason));
+    }
 }
 
 QGraphicsWidget* NetworkManagerApplet::graphicsWidget()
@@ -392,8 +395,14 @@ void NetworkManagerApplet::constraintsEvent(Plasma::Constraints constraints)
 
 void NetworkManagerApplet::updatePixmap()
 {
+    QString iconName = UiUtils::iconName(m_activeSystrayInterface);
+    if (iconName == m_currentPixmapIconName) {
+        return;
+    }
+
     int s = UiUtils::iconSize(contentsRect().size());
-    m_pixmap = KIcon(UiUtils::iconName(m_activeSystrayInterface)).pixmap(s, s);
+    m_currentPixmapIconName = iconName;
+    m_pixmap = KIcon(m_currentPixmapIconName).pixmap(s, s);
     update();
 }
 
@@ -408,6 +417,15 @@ void NetworkManagerApplet::paintInterface(QPainter * p, const QStyleOptionGraphi
         return;
     }
 
+    QString el = svgElement(m_activeSystrayInterface);
+
+    if ((el == m_currentSvgElement || (el.isEmpty() && m_currentSvgElement == m_currentPixmapIconName)) &&
+        !needToUpdateOverlay()) {
+        // no need to update systray icon
+        return;
+    }
+
+
     /* I am using setPopupIcon at the end of this method to make the usual system tray icon's hover and click
      * effects work. However, setPopupIcon creates a Plasma::IconWidget object that draws itself over
      * contentsRect and, consequentely, over the overlays created by paintStatusOverlay and paintNeedAuthOverlay.
@@ -424,11 +442,12 @@ void NetworkManagerApplet::paintInterface(QPainter * p, const QStyleOptionGraphi
     QPainter painter;
     painter.begin(&newIcon);
 
-    QString el = svgElement(m_activeSystrayInterface);
     if (el.isEmpty()) {
+        m_currentSvgElement = m_currentPixmapIconName;
         painter.drawPixmap(QPoint(0,0), m_pixmap);
     } else {
-        if (el.startsWith("network-mobile")) {
+        m_currentSvgElement = el;
+        if (el.startsWith(QLatin1String("network-mobile"))) {
             m_svgMobile->paint(&painter, rect, el);
         } else {
             m_svg->paint(&painter, rect, el);
@@ -441,17 +460,42 @@ void NetworkManagerApplet::paintInterface(QPainter * p, const QStyleOptionGraphi
     setPopupIcon(newIcon);
 }
 
+bool NetworkManagerApplet::needToUpdateOverlay()
+{
+    SystrayOverlayOptions temp;
+
+    if (m_activeSystrayInterface && m_activeSystrayInterface->connectionState() == Solid::Control::NetworkInterfaceNm09::NeedAuth) {
+        temp |= NetworkManagerApplet::NeedAuth;
+    }
+
+    if (m_totalActiveVpnConnections > 0) {
+        temp |= NetworkManagerApplet::Locked;
+    }
+
+    qreal opacity = m_overlayTimeline.currentValue();
+    if (!qFuzzyCompare(opacity, 1) && !m_previousStatusOverlay.isNull()) {
+        temp |= NetworkManagerApplet::PreviousOverlay;
+    }
+
+    if (!m_statusOverlay.isNull()) {
+        temp |= NetworkManagerApplet::StatusOverlay;
+    }
+
+    return (temp != m_systrayOverlayOption);
+}
+
 inline void NetworkManagerApplet::paintNeedAuthOverlay(QPainter *p, QRect &rect)
 {
     // Needs authentication, show this in the panel
     if (!m_activeSystrayInterface) {
+        m_systrayOverlayOption &= ~NetworkManagerApplet::NeedAuth;
         kDebug() << "No active interface";
         return;
     }
     /*
     kDebug() << "Painting overlay ...>" << m_activeSystrayInterface->connectionState();
     */
-    if (m_activeSystrayInterface && m_activeSystrayInterface->connectionState() == Solid::Control::NetworkInterfaceNm09::NeedAuth) {
+    if (m_activeSystrayInterface->connectionState() == Solid::Control::NetworkInterfaceNm09::NeedAuth) {
         //kDebug() << "Needing auth ...>";
         int iconSize = (int)2*(rect.width()/3);
 
@@ -461,6 +505,9 @@ inline void NetworkManagerApplet::paintNeedAuthOverlay(QPainter *p, QRect &rect)
                             rect.bottom() - iconSize);
 
         p->drawPixmap(pos, icon);
+        m_systrayOverlayOption |= NetworkManagerApplet::NeedAuth;
+    } else {
+        m_systrayOverlayOption &= ~NetworkManagerApplet::NeedAuth;
     }
 }
 
@@ -470,6 +517,9 @@ inline void NetworkManagerApplet::paintStatusOverlay(QPainter *p, QRect &rect)
         int iconSize = (int)2*(rect.width()/3);
         QPixmap pix = KIcon("object-locked").pixmap(iconSize);
         p->drawPixmap(rect.right() - pix.width(), rect.bottom() - pix.height(), pix);
+        m_systrayOverlayOption |= NetworkManagerApplet::Locked;
+    } else {
+        m_systrayOverlayOption &= ~NetworkManagerApplet::Locked;
     }
 
     int oldOpacity = p->opacity();
@@ -477,10 +527,17 @@ inline void NetworkManagerApplet::paintStatusOverlay(QPainter *p, QRect &rect)
     if (!qFuzzyCompare(opacity, 1) && !m_previousStatusOverlay.isNull()) {
         p->setOpacity(1 - opacity);
         p->drawPixmap(rect.left(), rect.bottom() - m_previousStatusOverlay.height(), m_previousStatusOverlay);
+        m_systrayOverlayOption |= NetworkManagerApplet::PreviousOverlay;
+    } else {
+        m_systrayOverlayOption &= ~NetworkManagerApplet::PreviousOverlay;
     }
+
     if (!m_statusOverlay.isNull()) {
         p->setOpacity(opacity);
         p->drawPixmap(rect.left(), rect.bottom() - m_statusOverlay.height(), m_statusOverlay);
+        m_systrayOverlayOption |= NetworkManagerApplet::StatusOverlay;
+    } else {
+        m_systrayOverlayOption &= ~NetworkManagerApplet::StatusOverlay;
     }
     p->setOpacity(oldOpacity);
 }
