@@ -1,6 +1,7 @@
 /*
 Copyright 2008,2009 Will Stephenson <wstephenson@kde.org>
 Copyright 2008-2010 Sebastian Kügler <sebas@kde.org>
+Copyright 2011-2012 Lamarque V. Souza <lamarque@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -187,15 +188,19 @@ void NMPopup::init()
 
     m_rightLayout->addItem(m_connectionList);
 
-    m_connectionsButton = new Plasma::PushButton(m_rightWidget);
-    m_connectionsButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
+    m_connectionsButton = new Plasma::IconWidget(m_rightWidget);
+    m_connectionsButton->setDrawBackground(true);
+    m_connectionsButton->setOrientation(Qt::Horizontal);
+    //m_connectionsButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
     m_connectionsButton->setIcon(KIcon("configure"));
     m_connectionsButton->setText(i18nc("manage connections button in the applet's popup", "Manage Connections..."));
     m_connectionsButton->setMinimumHeight(28);
     m_connectionsButton->setMaximumHeight(28);
     connect(m_connectionsButton, SIGNAL(clicked()), this, SLOT(manageConnections()));
 
-    m_showMoreButton = new Plasma::PushButton(m_rightWidget);
+    m_showMoreButton = new Plasma::IconWidget(this);
+    m_showMoreButton->setDrawBackground(true);
+    m_showMoreButton->setOrientation(Qt::Horizontal);
     m_showMoreButton->setToolTip(i18nc("@info:tooltip tooltip for the 'Show More' button", "Show all available networks"));
     // Do not use this according to KDE HIG. Bug #272492
     //m_showMoreButton->setCheckable(true);
@@ -211,8 +216,8 @@ void NMPopup::init()
     m_showMoreButton->setMinimumSize(sMax);
     m_showMoreButton->setMaximumSize(sMax);
     connect(m_showMoreButton, SIGNAL(clicked()), this, SLOT(showMore()));
-    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable *, int)), this, SLOT(uncheckShowMore(RemoteActivatable *)));
-    connect(m_activatables, SIGNAL(activatableRemoved(RemoteActivatable *)), this, SLOT(checkShowMore(RemoteActivatable *)));
+    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable*,int)), this, SLOT(uncheckShowMore(RemoteActivatable*)));
+    connect(m_activatables, SIGNAL(activatableRemoved(RemoteActivatable*)), this, SLOT(checkShowMore(RemoteActivatable*)));
 
     QGraphicsLinearLayout* connectionLayout = new QGraphicsLinearLayout;
     connectionLayout->addItem(m_showMoreButton);
@@ -231,10 +236,10 @@ void NMPopup::init()
     }
     addVpnInterface();
     // hook up signals to allow us to change the connection list depending on APs present, etc
-    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(const QString&)),
-            SLOT(interfaceAdded(const QString&)));
-    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(const QString&)),
-            SLOT(interfaceRemoved(const QString&)));
+    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(QString)),
+            SLOT(interfaceAdded(QString)));
+    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(QString)),
+            SLOT(interfaceRemoved(QString)));
 
     m_showMoreChecked = false;
     m_oldShowMoreChecked = true;
@@ -409,17 +414,17 @@ void NMPopup::addInterfaceInternal(Solid::Control::NetworkInterfaceNm09* iface)
             //connect(wirelessinterface, SIGNAL(stateChanged()), this, SLOT(updateNetworks()));
             wifiItem->setEnabled(Solid::Control::NetworkManagerNm09::isWirelessEnabled());
             kDebug() << "WiFi added";
-            connect(wifiItem, SIGNAL(disconnectInterfaceRequested(const QString&)), m_connectionList, SLOT(deactivateConnection(const QString&)));
+            connect(wifiItem, SIGNAL(disconnectInterfaceRequested(QString)), m_connectionList, SLOT(deactivateConnection(QString)));
         } else {
             // Create the interfaceitem
             ifaceItem = new InterfaceItem(static_cast<Solid::Control::WiredNetworkInterfaceNm09 *>(iface), m_activatables, InterfaceItem::InterfaceName, this);
-            connect(ifaceItem, SIGNAL(disconnectInterfaceRequested(const QString&)), m_connectionList, SLOT(deactivateConnection(const QString&)));
+            connect(ifaceItem, SIGNAL(disconnectInterfaceRequested(QString)), m_connectionList, SLOT(deactivateConnection(QString)));
         }
         connect(ifaceItem, SIGNAL(clicked()), this, SLOT(toggleInterfaceTab()));
         connect(ifaceItem, SIGNAL(clicked(Solid::Control::NetworkInterfaceNm09*)),
                 m_connectionList,  SLOT(addInterface(Solid::Control::NetworkInterfaceNm09*)));
-        connect(ifaceItem, SIGNAL(hoverEnter(const QString&)), m_connectionList, SLOT(hoverEnter(const QString&)));
-        connect(ifaceItem, SIGNAL(hoverLeave(const QString&)), m_connectionList, SLOT(hoverLeave(const QString&)));
+        connect(ifaceItem, SIGNAL(hoverEnter(QString)), m_connectionList, SLOT(hoverEnter(QString)));
+        connect(ifaceItem, SIGNAL(hoverLeave(QString)), m_connectionList, SLOT(hoverLeave(QString)));
 
         // Catch connection changes
         connect(iface, SIGNAL(connectionStateChanged(int,int,int)), this, SLOT(handleConnectionStateChange(int,int,int)));
