@@ -53,28 +53,26 @@ public:
         strength(-1),
         adhoc(false),
         iface(0),
-        activeAccessPoint(0)
+        activeAccessPoint(0),
+        activatable(0)
     {
     }
 
     void init(RemoteWirelessObject* wobj)
     {
-        if (!wobj) {
-            kDebug() << "wobj is null";
+        if (!wobj)
             return;
-        }
-
-        if (!wobj || !wobj->isValid()) {
-            kDebug() << "wobj is invalid";
-            return;
-        }
 
         if (wobj->operationMode() == Solid::Control::WirelessNetworkInterfaceNm09::Adhoc) {
             adhoc = true;
             //adhoc->setIcon(QIcon("nm-adhoc"));
         }
         ssid = wobj->ssid();
-        Knm::WirelessSecurity::Type best = Knm::WirelessSecurity::best(wobj->interfaceCapabilities(), true, (wobj->operationMode() == Solid::Control::WirelessNetworkInterfaceNm09::Adhoc), wobj->apCapabilities(), wobj->wpaFlags(), wobj->rsnFlags());
+        bool isShared = false;
+        if (activatable) {
+            isShared = activatable->isShared();
+        }
+        Knm::WirelessSecurity::Type best = Knm::WirelessSecurity::best(wobj->interfaceCapabilities(), !isShared, (wobj->operationMode() == Solid::Control::WirelessNetworkInterfaceNm09::Adhoc), wobj->apCapabilities(), wobj->wpaFlags(), wobj->rsnFlags());
         //security->setToolTip(Knm::WirelessSecurity::shortToolTip(best));
         securityIcon = Knm::WirelessSecurity::iconName(best);
         securityTooltip = Knm::WirelessSecurity::shortToolTip(best);
@@ -141,8 +139,8 @@ WirelessStatus::WirelessStatus(Solid::Control::WirelessNetworkInterfaceNm09 * if
 {
     Q_D(WirelessStatus);
 
-    connect(iface, SIGNAL(activeAccessPointChanged(const QString&)),
-        SLOT(activeAccessPointChanged(const QString&)));
+    connect(iface, SIGNAL(activeAccessPointChanged(QString)),
+        SLOT(activeAccessPointChanged(QString)));
 
     d->init(iface);
     activeAccessPointChanged(d->iface->uni());
