@@ -180,7 +180,7 @@ void TtlsWidget::showAltSubjectMatchesEditor()
     EditListDialog editor;
     editor.setItems(leAltSubjectMatches->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), QString::SkipEmptyParts));
     editor.setCaption(i18n("Alternative Subject Matches"));
-    editor.setToolTip(i18n("<qt>This entry must be one of:<ul><li>DNS: &lt;name or ip address&gt;</li><li>EMAIL: &lt;email&gt;</li><li>URI: &lt;uri, e.g. http://www.kde.org&gt;</li><ul></qt>"));
+    editor.setToolTip(i18n("<qt>This entry must be one of:<ul><li>DNS: &lt;name or ip address&gt;</li><li>EMAIL: &lt;email&gt;</li><li>URI: &lt;uri, e.g. http://www.kde.org&gt;</li></ul></qt>"));
     editor.setValidator(d->altSubjectValidator);
     if (editor.exec() == QDialog::Accepted) {
         leAltSubjectMatches->setText(editor.items().join(QLatin1String(", ")));
@@ -199,4 +199,16 @@ void TtlsWidget::showServersEditor()
     }
 }
 
+void TtlsWidget::syncWidgetData(const QPair<QString, QString> &widgetData)
+{
+    Q_D(TtlsWidget);
+    d->innerAuth->syncWidgetData(widgetData);
+}
+
+QPair<QString, QString> TtlsWidget::widgetData()
+{
+    Q_D(TtlsWidget);
+    return d->innerAuth->widgetData();
+}
+
 // vim: sw=4 sts=4 et tw=100
