@@ -46,10 +46,10 @@ Solid::Control::NetworkManagerNm09Private::NetworkManagerNm09Private() : m_inval
                 "Solid::Control::Ifaces::NetworkManagerNm09");
 
     if (managerBackend()!=0) {
-        connect(managerBackend(), SIGNAL(networkInterfaceAdded(const QString &)),
-                this, SLOT(_k_networkInterfaceAdded(const QString &)));
-        connect(managerBackend(), SIGNAL(networkInterfaceRemoved(const QString &)),
-                this, SLOT(_k_networkInterfaceRemoved(const QString &)));
+        connect(managerBackend(), SIGNAL(networkInterfaceAdded(QString)),
+                this, SLOT(_k_networkInterfaceAdded(QString)));
+        connect(managerBackend(), SIGNAL(networkInterfaceRemoved(QString)),
+                this, SLOT(_k_networkInterfaceRemoved(QString)));
         connect(managerBackend(), SIGNAL(statusChanged(Solid::Networking::Status)),
                 this, SIGNAL(statusChanged(Solid::Networking::Status)));
         connect(managerBackend(), SIGNAL(wirelessEnabledChanged(bool)),
@@ -110,7 +110,7 @@ Solid::Control::NetworkInterfaceNm09List Solid::Control::NetworkManagerNm09Priva
     }
     else
     {
-        kWarning() << "NetworkManager backend not found" << managerBackend() << managerBackend()->inherits("Solid::Control::Ifaces::NetworkManagerNm09") << managerBackend()->metaObject()->className();
+        kWarning() << "NetworkManager backend not found";
         return NetworkInterfaceNm09List();
     }
 }
@@ -277,8 +277,8 @@ Solid::Control::NetworkManagerNm09Private::findRegisteredNetworkInterface(const
             }
             if (device != 0) {
                 QPair<NetworkInterfaceNm09 *, QObject *> pair(device, iface);
-                connect(iface, SIGNAL(destroyed(QObject *)),
-                        this, SLOT(_k_destroyed(QObject *)));
+                connect(iface, SIGNAL(destroyed(QObject*)),
+                        this, SLOT(_k_destroyed(QObject*)));
                 m_networkInterfaceMap[uni] = pair;
                 return pair;
             }
